==> open-xchange-core_6.22.1.orig.tar.bz2: open-xchange-core-6.22.1/com.openexchange.file.storage.config/src/com/openexchange/file/storage/config/internal/ConfigFileStorageAccountImpl.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.file.storage.config.internal;

import java.util.HashMap;
import java.util.Map;
import com.openexchange.file.storage.FileStorageAccount;
import com.openexchange.file.storage.config.ConfigFileStorageAccount;
import com.openexchange.file.storage.generic.DefaultFileStorageAccount;

/**
 * {@link ConfigFileStorageAccountImpl} - The configuration {@link FileStorageAccount} implementation.
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 * @since Open-Xchange v6.18.2
 */
public class ConfigFileStorageAccountImpl extends DefaultFileStorageAccount implements ConfigFileStorageAccount {

    private static final long serialVersionUID = -1711683802127778909L;

    /**
     * Initializes a new {@link ConfigFileStorageAccountImpl}.
     */
    public ConfigFileStorageAccountImpl() {
        super();
    }

    @Override
    public Object clone() {
        try {
            final ConfigFileStorageAccountImpl clone = (ConfigFileStorageAccountImpl) super.clone();
            clone.setFileStorageService(null);
            final Map<String, Object> thismap = this.configuration;
            final Map<String, Object> clonedConfig = null == thismap ? null : new HashMap<String, Object>(thismap);
            clone.configuration = clonedConfig;
            return clone;
        } catch (final CloneNotSupportedException e) {
            throw new InternalError("Clone not supported although Cloneable is implemented.");
        }
    }

    @Override
    public String toString() {
        final StringBuilder sb = new StringBuilder(256).append(ConfigFileStorageAccountImpl.class.getSimpleName());
        sb.append(" ( serviceId=").append(this.serviceId);
        sb.append(", configuration=").append(null == configuration ? "<empty>" : configuration.toString()).append(" )").toString();
        return sb.toString();
    }

}

==> open-xchange-core_7.4.2.orig.tar.bz2: open-xchange-core-7.4.2/com.openexchange.file.storage.config/src/com/openexchange/file/storage/config/internal/ConfigFileStorageAccountImpl.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.file.storage.config.internal;

import java.util.HashMap;
import java.util.Map;
import com.openexchange.file.storage.FileStorageAccount;
import com.openexchange.file.storage.config.ConfigFileStorageAccount;
import com.openexchange.file.storage.generic.DefaultFileStorageAccount;

/**
 * {@link ConfigFileStorageAccountImpl} - The configuration {@link FileStorageAccount} implementation.
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 * @since Open-Xchange v6.18.2
 */
public class ConfigFileStorageAccountImpl extends DefaultFileStorageAccount implements ConfigFileStorageAccount {

    private static final long serialVersionUID = -1711683802127778909L;

    /**
     * Initializes a new {@link ConfigFileStorageAccountImpl}.
     */
    public ConfigFileStorageAccountImpl() {
        super();
    }

    @Override
    public Object clone() {
        try {
            final ConfigFileStorageAccountImpl clone = (ConfigFileStorageAccountImpl) super.clone();
            clone.setFileStorageService(null);
            final Map<String, Object> thismap = this.configuration;
            final Map<String, Object> clonedConfig = null == thismap ? null : new HashMap<String, Object>(thismap);
            clone.configuration = clonedConfig;
            return clone;
        } catch (final CloneNotSupportedException e) {
            throw new InternalError("Clone not supported although Cloneable is implemented.");
        }
    }

    @Override
    public String toString() {
        final com.openexchange.java.StringAllocator sb = new com.openexchange.java.StringAllocator(256).append(ConfigFileStorageAccountImpl.class.getSimpleName());
        sb.append(" ( serviceId=").append(this.serviceId);
        sb.append(", configuration=").append(null == configuration ? "<empty>" : configuration.toString()).append(" )").toString();
        return sb.toString();
    }

}
